/*
 * font8x16.h
 *
 * Simple 8 x 16 font printable characters only.  To lookoup, subtract 
 * FIRST_CHAR from the character, multiply x FONT_HEIGHT and get the next
 * FONT_WIDTH bytes.
 *
 *  Based upon code from MicroMonitor 1.17 from http://www.umonfw.com/
 *  which includes this notice:
 *
 **************************************************************************
 *  General notice:
 *  This code is part of a boot-monitor package developed as a generic base
 *  platform for embedded system designs.  As such, it is likely to be
 *  distributed to various projects beyond the control of the original
 *  author.  Please notify the author of any enhancements made or bugs found
 *  so that all may benefit from the changes.  In addition, notification back
 *  to the author will allow the new user to pick up changes that may have
 *  been made by other users after this version of the code was distributed.
 *
 *  Note1: the majority of this code was edited with 4-space tabs.
 *  Note2: as more and more contributions are accepted, the term "author"
 *         is becoming a mis-representation of credit.
 *
 *  Original author:    Ed Sutter
 *  Email:              esutter@alcatel-lucent.com
 *  Phone:              908-582-2351
 **************************************************************************
 *
 *  Ed Sutter has been informed that this code is being used in RTEMS.
 *
 *  The code has been reformatted to be more compliant with RTEMS
 *  coding standards and to eliminate C++ style comments.
 *
 *  $Id$
 */

#define FONT_WIDTH		8
#define FONT_HEIGHT 	16
#define FIRST_CHAR 		0x20
#define LAST_CHAR 		0x7f  
#define CURSOR_ON  		0x7F
#define CURSOR_OFF 		0x20

const uint8_t	font8x16[] = {


/* Character   (0x20):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ! (0x21):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |   **   |
   |  ****  |
   |  ****  |
   |  ****  |
   |  ****  |
   |   **   |
   |   **   |
   |        |
   |   **   |
   |   **   |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x18,
0x3c,
0x3c,
0x3c,
0x3c,
0x18,
0x18,
0x00,
0x18,
0x18,
0x00,
0x00,
0x00,
0x00,

/* Character " (0x22):
   ht=16, width=8
   +--------+
   |        |
   |  ** ** |
   |  ** ** |
   |  ** ** |
   |  ** ** |
   |   * *  |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x36,
0x36,
0x36,
0x36,
0x14,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character # (0x23):
   ht=16, width=8
   +--------+
   |        |
   |        |
   | ** **  |
   | ** **  |
   | ** **  |
   |******* |
   | ** **  |
   | ** **  |
   |******* |
   | ** **  |
   | ** **  |
   | ** **  |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x6c,
0x6c,
0x6c,
0xfe,
0x6c,
0x6c,
0xfe,
0x6c,
0x6c,
0x6c,
0x00,
0x00,
0x00,
0x00,

/* Character $ (0x24):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |   **   |
   |   **   |
   | *****  |
   |**   ** |
   |**      |
   | ****   |
   |  ****  |
   |     ** |
   |**   ** |
   | *****  |
   |   **   |
   |   **   |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x18,
0x18,
0x7c,
0xc6,
0xc0,
0x78,
0x3c,
0x06,
0xc6,
0x7c,
0x18,
0x18,
0x00,
0x00,

/* Character % (0x25):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   | **   * |
   | **  ** |
   |    **  |
   |   **   |
   |  **    |
   | **  ** |
   |**   ** |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x62,
0x66,
0x0c,
0x18,
0x30,
0x66,
0xc6,
0x00,
0x00,
0x00,
0x00,

/* Character & (0x26):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |  ***   |
   | ** **  |
   |  ***   |
   |  **    |
   | *** ** |
   | ****** |
   |**  **  |
   |**  **  |
   |**  **  |
   | *** ** |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x38,
0x6c,
0x38,
0x30,
0x76,
0x7e,
0xcc,
0xcc,
0xcc,
0x76,
0x00,
0x00,
0x00,
0x00,

/* Character ' (0x27):
   ht=16, width=8
   +--------+
   |        |
   |    **  |
   |    **  |
   |    **  |
   |   **   |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x0c,
0x0c,
0x0c,
0x18,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ( (0x28):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |    **  |
   |   **   |
   |  **    |
   |  **    |
   |  **    |
   |  **    |
   |  **    |
   |  **    |
   |   **   |
   |    **  |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x0c,
0x18,
0x30,
0x30,
0x30,
0x30,
0x30,
0x30,
0x18,
0x0c,
0x00,
0x00,
0x00,
0x00,

/* Character ) (0x29):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |  **    |
   |   **   |
   |    **  |
   |    **  |
   |    **  |
   |    **  |
   |    **  |
   |    **  |
   |   **   |
   |  **    |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x30,
0x18,
0x0c,
0x0c,
0x0c,
0x0c,
0x0c,
0x0c,
0x18,
0x30,
0x00,
0x00,
0x00,
0x00,

/* Character * (0x2a):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   | ** **  |
   |  ***   |
   |******* |
   |  ***   |
   | ** **  |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x6c,
0x38,
0xfe,
0x38,
0x6c,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character + (0x2b):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   |   **   |
   |   **   |
   | ****** |
   |   **   |
   |   **   |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x18,
0x18,
0x7e,
0x18,
0x18,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character , (0x2c):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |    **  |
   |    **  |
   |    **  |
   |   **   |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x0c,
0x0c,
0x0c,
0x18,
0x00,
0x00,
0x00,

/* Character - (0x2d):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |******* |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0xfe,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character . (0x2e):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |   **   |
   |   **   |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x18,
0x18,
0x00,
0x00,
0x00,
0x00,

/* Character / (0x2f):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |      * |
   |     ** |
   |    **  |
   |   **   |
   |  **    |
   | **     |
   |**      |
   |*       |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x02,
0x06,
0x0c,
0x18,
0x30,
0x60,
0xc0,
0x80,
0x00,
0x00,
0x00,
0x00,

/* Character 0 (0x30):
   ht=16, width=8
   +--------+
   |        |
   |        |
   | *****  |
   |**   ** |
   |**   ** |
   |**  *** |
   |** **** |
   |**** ** |
   |***  ** |
   |**   ** |
   |**   ** |
   | *****  |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x7c,
0xc6,
0xc6,
0xce,
0xde,
0xf6,
0xe6,
0xc6,
0xc6,
0x7c,
0x00,
0x00,
0x00,
0x00,

/* Character 1 (0x31):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |   **   |
   | ****   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   | ****** |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x18,
0x78,
0x18,
0x18,
0x18,
0x18,
0x18,
0x18,
0x18,
0x7e,
0x00,
0x00,
0x00,
0x00,

/* Character 2 (0x32):
   ht=16, width=8
   +--------+
   |        |
   |        |
   | *****  |
   |**   ** |
   |**   ** |
   |     ** |
   |    **  |
   |   **   |
   |  **    |
   | **     |
   |**   ** |
   |******* |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x7c,
0xc6,
0xc6,
0x06,
0x0c,
0x18,
0x30,
0x60,
0xc6,
0xfe,
0x00,
0x00,
0x00,
0x00,

/* Character 3 (0x33):
   ht=16, width=8
   +--------+
   |        |
   |        |
   | *****  |
   |**   ** |
   |     ** |
   |     ** |
   |  ****  |
   |     ** |
   |     ** |
   |     ** |
   |**   ** |
   | *****  |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x7c,
0xc6,
0x06,
0x06,
0x3c,
0x06,
0x06,
0x06,
0xc6,
0x7c,
0x00,
0x00,
0x00,
0x00,

/* Character 4 (0x34):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |    **  |
   |   ***  |
   |  ****  |
   | ** **  |
   |**  **  |
   |**  **  |
   |******* |
   |    **  |
   |    **  |
   |   **** |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x0c,
0x1c,
0x3c,
0x6c,
0xcc,
0xcc,
0xfe,
0x0c,
0x0c,
0x1e,
0x00,
0x00,
0x00,
0x00,

/* Character 5 (0x35):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |******* |
   |**      |
   |**      |
   |**      |
   |******  |
   |     ** |
   |     ** |
   |     ** |
   |**   ** |
   | *****  |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0xfe,
0xc0,
0xc0,
0xc0,
0xfc,
0x06,
0x06,
0x06,
0xc6,
0x7c,
0x00,
0x00,
0x00,
0x00,

/* Character 6 (0x36):
   ht=16, width=8
   +--------+
   |        |
   |        |
   | *****  |
   |**   ** |
   |**      |
   |**      |
   |******  |
   |**   ** |
   |**   ** |
   |**   ** |
   |**   ** |
   | *****  |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x7c,
0xc6,
0xc0,
0xc0,
0xfc,
0xc6,
0xc6,
0xc6,
0xc6,
0x7c,
0x00,
0x00,
0x00,
0x00,

/* Character 7 (0x37):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |******* |
   |**   ** |
   |     ** |
   |    **  |
   |   **   |
   |  **    |
   |  **    |
   |  **    |
   |  **    |
   |  **    |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0xfe,
0xc6,
0x06,
0x0c,
0x18,
0x30,
0x30,
0x30,
0x30,
0x30,
0x00,
0x00,
0x00,
0x00,

/* Character 8 (0x38):
   ht=16, width=8
   +--------+
   |        |
   |        |
   | *****  |
   |**   ** |
   |**   ** |
   |**   ** |
   | *****  |
   |**   ** |
   |**   ** |
   |**   ** |
   |**   ** |
   | *****  |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x7c,
0xc6,
0xc6,
0xc6,
0x7c,
0xc6,
0xc6,
0xc6,
0xc6,
0x7c,
0x00,
0x00,
0x00,
0x00,

/* Character 9 (0x39):
   ht=16, width=8
   +--------+
   |        |
   |        |
   | *****  |
   |**   ** |
   |**   ** |
   |**   ** |
   |**   ** |
   | ****** |
   |     ** |
   |     ** |
   |**   ** |
   | *****  |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x7c,
0xc6,
0xc6,
0xc6,
0xc6,
0x7e,
0x06,
0x06,
0xc6,
0x7c,
0x00,
0x00,
0x00,
0x00,

/* Character : (0x3a):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   |    **  |
   |    **  |
   |        |
   |        |
   |    **  |
   |    **  |
   |        |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x0c,
0x0c,
0x00,
0x00,
0x0c,
0x0c,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ; (0x3b):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   |    **  |
   |    **  |
   |        |
   |        |
   |    **  |
   |    **  |
   |    **  |
   |   **   |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x0c,
0x0c,
0x00,
0x00,
0x0c,
0x0c,
0x0c,
0x18,
0x00,
0x00,
0x00,

/* Character < (0x3c):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   |    **  |
   |   **   |
   |  **    |
   | **     |
   |**      |
   | **     |
   |  **    |
   |   **   |
   |    **  |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x0c,
0x18,
0x30,
0x60,
0xc0,
0x60,
0x30,
0x18,
0x0c,
0x00,
0x00,
0x00,
0x00,

/* Character = (0x3d):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |******* |
   |        |
   |******* |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0xfe,
0x00,
0xfe,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character > (0x3e):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   | **     |
   |  **    |
   |   **   |
   |    **  |
   |     ** |
   |    **  |
   |   **   |
   |  **    |
   | **     |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x60,
0x30,
0x18,
0x0c,
0x06,
0x0c,
0x18,
0x30,
0x60,
0x00,
0x00,
0x00,
0x00,

/* Character ? (0x3f):
   ht=16, width=8
   +--------+
   |        |
   |        |
   | *****  |
   |**   ** |
   |**   ** |
   |    **  |
   |   **   |
   |   **   |
   |   **   |
   |        |
   |   **   |
   |   **   |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x7c,
0xc6,
0xc6,
0x0c,
0x18,
0x18,
0x18,
0x00,
0x18,
0x18,
0x00,
0x00,
0x00,
0x00,

/* Character @ (0x40):
   ht=16, width=8
   +--------+
   |        |
   |        |
   | *****  |
   |**   ** |
   |**   ** |
   |**   ** |
   |** **** |
   |** **** |
   |** **** |
   |** ***  |
   |**      |
   | ****** |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x7c,
0xc6,
0xc6,
0xc6,
0xde,
0xde,
0xde,
0xdc,
0xc0,
0x7e,
0x00,
0x00,
0x00,
0x00,

/* Character A (0x41):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |  ***   |
   | ** **  |
   |**   ** |
   |**   ** |
   |**   ** |
   |******* |
   |**   ** |
   |**   ** |
   |**   ** |
   |**   ** |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x38,
0x6c,
0xc6,
0xc6,
0xc6,
0xfe,
0xc6,
0xc6,
0xc6,
0xc6,
0x00,
0x00,
0x00,
0x00,

/* Character B (0x42):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |******  |
   | **  ** |
   | **  ** |
   | **  ** |
   | *****  |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   |******  |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0xfc,
0x66,
0x66,
0x66,
0x7c,
0x66,
0x66,
0x66,
0x66,
0xfc,
0x00,
0x00,
0x00,
0x00,

/* Character C (0x43):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |  ****  |
   | **  ** |
   |**    * |
   |**      |
   |**      |
   |**      |
   |**      |
   |**    * |
   | **  ** |
   |  ****  |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x3c,
0x66,
0xc2,
0xc0,
0xc0,
0xc0,
0xc0,
0xc2,
0x66,
0x3c,
0x00,
0x00,
0x00,
0x00,

/* Character D (0x44):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |*****   |
   | ** **  |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | ** **  |
   |*****   |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0xf8,
0x6c,
0x66,
0x66,
0x66,
0x66,
0x66,
0x66,
0x6c,
0xf8,
0x00,
0x00,
0x00,
0x00,

/* Character E (0x45):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |******* |
   | **  ** |
   | **     |
   | **  *  |
   | *****  |
   | **  *  |
   | **     |
   | **     |
   | **  ** |
   |******* |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0xfe,
0x66,
0x60,
0x64,
0x7c,
0x64,
0x60,
0x60,
0x66,
0xfe,
0x00,
0x00,
0x00,
0x00,

/* Character F (0x46):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |******* |
   | **  ** |
   | **     |
   | **  *  |
   | *****  |
   | **  *  |
   | **     |
   | **     |
   | **     |
   |****    |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0xfe,
0x66,
0x60,
0x64,
0x7c,
0x64,
0x60,
0x60,
0x60,
0xf0,
0x00,
0x00,
0x00,
0x00,

/* Character G (0x47):
   ht=16, width=8
   +--------+
   |        |
   |        |
   | *****  |
   |**   ** |
   |**   ** |
   |**      |
   |**      |
   |**      |
   |**  *** |
   |**   ** |
   |**   ** |
   | *****  |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x7c,
0xc6,
0xc6,
0xc0,
0xc0,
0xc0,
0xce,
0xc6,
0xc6,
0x7c,
0x00,
0x00,
0x00,
0x00,

/* Character H (0x48):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |**   ** |
   |**   ** |
   |**   ** |
   |**   ** |
   |******* |
   |**   ** |
   |**   ** |
   |**   ** |
   |**   ** |
   |**   ** |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0xc6,
0xc6,
0xc6,
0xc6,
0xfe,
0xc6,
0xc6,
0xc6,
0xc6,
0xc6,
0x00,
0x00,
0x00,
0x00,

/* Character I (0x49):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |  ****  |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |  ****  |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x3c,
0x18,
0x18,
0x18,
0x18,
0x18,
0x18,
0x18,
0x18,
0x3c,
0x00,
0x00,
0x00,
0x00,

/* Character J (0x4a):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |  ****  |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |** **   |
   |** **   |
   | ***    |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x3c,
0x18,
0x18,
0x18,
0x18,
0x18,
0x18,
0xd8,
0xd8,
0x70,
0x00,
0x00,
0x00,
0x00,

/* Character K (0x4b):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |**   ** |
   |**   ** |
   |**  **  |
   |** **   |
   |****    |
   |****    |
   |** **   |
   |**  **  |
   |**   ** |
   |**   ** |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0xc6,
0xc6,
0xcc,
0xd8,
0xf0,
0xf0,
0xd8,
0xcc,
0xc6,
0xc6,
0x00,
0x00,
0x00,
0x00,

/* Character L (0x4c):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |****    |
   | **     |
   | **     |
   | **     |
   | **     |
   | **     |
   | **     |
   | **   * |
   | **  ** |
   |******* |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0xf0,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x62,
0x66,
0xfe,
0x00,
0x00,
0x00,
0x00,

/* Character M (0x4d):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |**   ** |
   |**   ** |
   |*** *** |
   |*** *** |
   |******* |
   |** * ** |
   |** * ** |
   |** * ** |
   |**   ** |
   |**   ** |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0xc6,
0xc6,
0xee,
0xee,
0xfe,
0xd6,
0xd6,
0xd6,
0xc6,
0xc6,
0x00,
0x00,
0x00,
0x00,

/* Character N (0x4e):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |**   ** |
   |**   ** |
   |***  ** |
   |***  ** |
   |**** ** |
   |** **** |
   |**  *** |
   |**  *** |
   |**   ** |
   |**   ** |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0xc6,
0xc6,
0xe6,
0xe6,
0xf6,
0xde,
0xce,
0xce,
0xc6,
0xc6,
0x00,
0x00,
0x00,
0x00,

/* Character O (0x4f):
   ht=16, width=8
   +--------+
   |        |
   |        |
   | *****  |
   |**   ** |
   |**   ** |
   |**   ** |
   |**   ** |
   |**   ** |
   |**   ** |
   |**   ** |
   |**   ** |
   | *****  |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x7c,
0xc6,
0xc6,
0xc6,
0xc6,
0xc6,
0xc6,
0xc6,
0xc6,
0x7c,
0x00,
0x00,
0x00,
0x00,

/* Character P (0x50):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |******  |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | *****  |
   | **     |
   | **     |
   | **     |
   |****    |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0xfc,
0x66,
0x66,
0x66,
0x66,
0x7c,
0x60,
0x60,
0x60,
0xf0,
0x00,
0x00,
0x00,
0x00,

/* Character Q (0x51):
   ht=16, width=8
   +--------+
   |        |
   |        |
   | *****  |
   |**   ** |
   |**   ** |
   |**   ** |
   |**   ** |
   |**   ** |
   |**   ** |
   |** * ** |
   |** * ** |
   | *****  |
   |     ** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x7c,
0xc6,
0xc6,
0xc6,
0xc6,
0xc6,
0xc6,
0xd6,
0xd6,
0x7c,
0x06,
0x00,
0x00,
0x00,

/* Character R (0x52):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |******  |
   | **  ** |
   | **  ** |
   | **  ** |
   | *****  |
   | ****   |
   | ** **  |
   | **  ** |
   | **  ** |
   |***  ** |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0xfc,
0x66,
0x66,
0x66,
0x7c,
0x78,
0x6c,
0x66,
0x66,
0xe6,
0x00,
0x00,
0x00,
0x00,

/* Character S (0x53):
   ht=16, width=8
   +--------+
   |        |
   |        |
   | *****  |
   |**   ** |
   |**      |
   |**      |
   | ***    |
   |   ***  |
   |     ** |
   |     ** |
   |**   ** |
   | *****  |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x7c,
0xc6,
0xc0,
0xc0,
0x70,
0x1c,
0x06,
0x06,
0xc6,
0x7c,
0x00,
0x00,
0x00,
0x00,

/* Character T (0x54):
   ht=16, width=8
   +--------+
   |        |
   |        |
   | ****** |
   | * ** * |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |  ****  |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x7e,
0x5a,
0x18,
0x18,
0x18,
0x18,
0x18,
0x18,
0x18,
0x3c,
0x00,
0x00,
0x00,
0x00,

/* Character U (0x55):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |**   ** |
   |**   ** |
   |**   ** |
   |**   ** |
   |**   ** |
   |**   ** |
   |**   ** |
   |**   ** |
   |**   ** |
   | *****  |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0xc6,
0xc6,
0xc6,
0xc6,
0xc6,
0xc6,
0xc6,
0xc6,
0xc6,
0x7c,
0x00,
0x00,
0x00,
0x00,

/* Character V (0x56):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |**   ** |
   |**   ** |
   |**   ** |
   |**   ** |
   |**   ** |
   |**   ** |
   |**   ** |
   | ** **  |
   |  ***   |
   |   *    |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0xc6,
0xc6,
0xc6,
0xc6,
0xc6,
0xc6,
0xc6,
0x6c,
0x38,
0x10,
0x00,
0x00,
0x00,
0x00,

/* Character W (0x57):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |**   ** |
   |**   ** |
   |**   ** |
   |** * ** |
   |** * ** |
   |** * ** |
   |******* |
   |*** *** |
   |**   ** |
   |**   ** |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0xc6,
0xc6,
0xc6,
0xd6,
0xd6,
0xd6,
0xfe,
0xee,
0xc6,
0xc6,
0x00,
0x00,
0x00,
0x00,

/* Character X (0x58):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |**   ** |
   |**   ** |
   |**   ** |
   | ** **  |
   |  ***   |
   |  ***   |
   | ** **  |
   |**   ** |
   |**   ** |
   |**   ** |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0xc6,
0xc6,
0xc6,
0x6c,
0x38,
0x38,
0x6c,
0xc6,
0xc6,
0xc6,
0x00,
0x00,
0x00,
0x00,

/* Character Y (0x59):
   ht=16, width=8
   +--------+
   |        |
   |        |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   |  ****  |
   |   **   |
   |   **   |
   |   **   |
   |  ****  |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x66,
0x66,
0x66,
0x66,
0x66,
0x3c,
0x18,
0x18,
0x18,
0x3c,
0x00,
0x00,
0x00,
0x00,

/* Character Z (0x5a):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |******* |
   |**   ** |
   |*    ** |
   |    **  |
   |   **   |
   |  **    |
   | **     |
   |**    * |
   |**   ** |
   |******* |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0xfe,
0xc6,
0x86,
0x0c,
0x18,
0x30,
0x60,
0xc2,
0xc6,
0xfe,
0x00,
0x00,
0x00,
0x00,

/* Character [ (0x5b):
   ht=16, width=8
   +--------+
   |        |
   |        |
   | *****  |
   | **     |
   | **     |
   | **     |
   | **     |
   | **     |
   | **     |
   | **     |
   | **     |
   | *****  |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x7c,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x7c,
0x00,
0x00,
0x00,
0x00,

/* Character \ (0x5c):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |*       |
   |**      |
   | **     |
   |  **    |
   |   **   |
   |    **  |
   |     ** |
   |      * |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x80,
0xc0,
0x60,
0x30,
0x18,
0x0c,
0x06,
0x02,
0x00,
0x00,
0x00,
0x00,

/* Character ] (0x5d):
   ht=16, width=8
   +--------+
   |        |
   |        |
   | *****  |
   |    **  |
   |    **  |
   |    **  |
   |    **  |
   |    **  |
   |    **  |
   |    **  |
   |    **  |
   | *****  |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x7c,
0x0c,
0x0c,
0x0c,
0x0c,
0x0c,
0x0c,
0x0c,
0x0c,
0x7c,
0x00,
0x00,
0x00,
0x00,

/* Character ^ (0x5e):
   ht=16, width=8
   +--------+
   |        |
   |   *    |
   |  ***   |
   | ** **  |
   |**   ** |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x10,
0x38,
0x6c,
0xc6,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character _ (0x5f):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |********|
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0xff,
0x00,
0x00,

/* Character ` (0x60):
   ht=16, width=8
   +--------+
   |        |
   |   **   |
   |   **   |
   |   **   |
   |    **  |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x18,
0x18,
0x18,
0x0c,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character a (0x61):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   | ****   |
   |    **  |
   | *****  |
   |**  **  |
   |**  **  |
   |** ***  |
   | *** ** |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x78,
0x0c,
0x7c,
0xcc,
0xcc,
0xdc,
0x76,
0x00,
0x00,
0x00,
0x00,

/* Character b (0x62):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |***     |
   | **     |
   | **     |
   | *****  |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   |******  |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0xe0,
0x60,
0x60,
0x7c,
0x66,
0x66,
0x66,
0x66,
0x66,
0xfc,
0x00,
0x00,
0x00,
0x00,

/* Character c (0x63):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   | *****  |
   |**   ** |
   |**      |
   |**      |
   |**      |
   |**   ** |
   | *****  |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x7c,
0xc6,
0xc0,
0xc0,
0xc0,
0xc6,
0x7c,
0x00,
0x00,
0x00,
0x00,

/* Character d (0x64):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |   ***  |
   |    **  |
   |    **  |
   | *****  |
   |**  **  |
   |**  **  |
   |**  **  |
   |**  **  |
   |**  **  |
   | ****** |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x1c,
0x0c,
0x0c,
0x7c,
0xcc,
0xcc,
0xcc,
0xcc,
0xcc,
0x7e,
0x00,
0x00,
0x00,
0x00,

/* Character e (0x65):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   | *****  |
   |**   ** |
   |**   ** |
   |******* |
   |**      |
   |**   ** |
   | *****  |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x7c,
0xc6,
0xc6,
0xfe,
0xc0,
0xc6,
0x7c,
0x00,
0x00,
0x00,
0x00,

/* Character f (0x66):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |   ***  |
   |  ** ** |
   |  **    |
   |  **    |
   |******  |
   |  **    |
   |  **    |
   |  **    |
   |  **    |
   | ****   |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x1c,
0x36,
0x30,
0x30,
0xfc,
0x30,
0x30,
0x30,
0x30,
0x78,
0x00,
0x00,
0x00,
0x00,

/* Character g (0x67):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   | *** ** |
   |**  *** |
   |**   ** |
   |**   ** |
   |**  *** |
   | *** ** |
   |     ** |
   |**   ** |
   | *****  |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x76,
0xce,
0xc6,
0xc6,
0xce,
0x76,
0x06,
0xc6,
0x7c,
0x00,
0x00,

/* Character h (0x68):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |***     |
   | **     |
   | **     |
   | *****  |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   |***  ** |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0xe0,
0x60,
0x60,
0x7c,
0x66,
0x66,
0x66,
0x66,
0x66,
0xe6,
0x00,
0x00,
0x00,
0x00,

/* Character i (0x69):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |   **   |
   |   **   |
   |        |
   |  ***   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |  ****  |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x18,
0x18,
0x00,
0x38,
0x18,
0x18,
0x18,
0x18,
0x18,
0x3c,
0x00,
0x00,
0x00,
0x00,

/* Character j (0x6a):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |    **  |
   |    **  |
   |        |
   |   ***  |
   |    **  |
   |    **  |
   |    **  |
   |    **  |
   |    **  |
   |**  **  |
   |**  **  |
   | ****   |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x0c,
0x0c,
0x00,
0x1c,
0x0c,
0x0c,
0x0c,
0x0c,
0x0c,
0xcc,
0xcc,
0x78,
0x00,
0x00,

/* Character k (0x6b):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |***     |
   | **     |
   | **     |
   | **  ** |
   | **  ** |
   | ** **  |
   | ****   |
   | ** **  |
   | **  ** |
   |***  ** |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0xe0,
0x60,
0x60,
0x66,
0x66,
0x6c,
0x78,
0x6c,
0x66,
0xe6,
0x00,
0x00,
0x00,
0x00,

/* Character l (0x6c):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   ***  |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x18,
0x18,
0x18,
0x18,
0x18,
0x18,
0x18,
0x18,
0x18,
0x1c,
0x00,
0x00,
0x00,
0x00,

/* Character m (0x6d):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   | ** **  |
   |******* |
   |** * ** |
   |** * ** |
   |**   ** |
   |**   ** |
   |**   ** |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x6c,
0xfe,
0xd6,
0xd6,
0xc6,
0xc6,
0xc6,
0x00,
0x00,
0x00,
0x00,

/* Character n (0x6e):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   |** ***  |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0xdc,
0x66,
0x66,
0x66,
0x66,
0x66,
0x66,
0x00,
0x00,
0x00,
0x00,

/* Character o (0x6f):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   | *****  |
   |**   ** |
   |**   ** |
   |**   ** |
   |**   ** |
   |**   ** |
   | *****  |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x7c,
0xc6,
0xc6,
0xc6,
0xc6,
0xc6,
0x7c,
0x00,
0x00,
0x00,
0x00,

/* Character p (0x70):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   |** ***  |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | *****  |
   | **     |
   | **     |
   |****    |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0xdc,
0x66,
0x66,
0x66,
0x66,
0x7c,
0x60,
0x60,
0xf0,
0x00,
0x00,

/* Character q (0x71):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   | *** ** |
   |**  **  |
   |**  **  |
   |**  **  |
   |**  **  |
   | *****  |
   |    **  |
   |    **  |
   |   **** |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x76,
0xcc,
0xcc,
0xcc,
0xcc,
0x7c,
0x0c,
0x0c,
0x1e,
0x00,
0x00,

/* Character r (0x72):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   |** ***  |
   | **  ** |
   | **     |
   | **     |
   | **     |
   | **     |
   |****    |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0xdc,
0x66,
0x60,
0x60,
0x60,
0x60,
0xf0,
0x00,
0x00,
0x00,
0x00,

/* Character s (0x73):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   | *****  |
   |**   ** |
   |**      |
   | *****  |
   |     ** |
   |**   ** |
   | *****  |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x7c,
0xc6,
0xc0,
0x7c,
0x06,
0xc6,
0x7c,
0x00,
0x00,
0x00,
0x00,

/* Character t (0x74):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |  **    |
   |  **    |
   |  **    |
   |******  |
   |  **    |
   |  **    |
   |  **    |
   |  **    |
   |  ** ** |
   |   ***  |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x30,
0x30,
0x30,
0xfc,
0x30,
0x30,
0x30,
0x30,
0x36,
0x1c,
0x00,
0x00,
0x00,
0x00,

/* Character u (0x75):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   |**  **  |
   |**  **  |
   |**  **  |
   |**  **  |
   |**  **  |
   |**  **  |
   | *** ** |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0xcc,
0xcc,
0xcc,
0xcc,
0xcc,
0xcc,
0x76,
0x00,
0x00,
0x00,
0x00,

/* Character v (0x76):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   |**   ** |
   |**   ** |
   |**   ** |
   |**   ** |
   | ** **  |
   |  ***   |
   |   *    |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0xc6,
0xc6,
0xc6,
0xc6,
0x6c,
0x38,
0x10,
0x00,
0x00,
0x00,
0x00,

/* Character w (0x77):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   |**   ** |
   |**   ** |
   |** * ** |
   |** * ** |
   |** * ** |
   |******* |
   | ** **  |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0xc6,
0xc6,
0xd6,
0xd6,
0xd6,
0xfe,
0x6c,
0x00,
0x00,
0x00,
0x00,

/* Character x (0x78):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   |**   ** |
   |**   ** |
   | ** **  |
   |  ***   |
   | ** **  |
   |**   ** |
   |**   ** |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0xc6,
0xc6,
0x6c,
0x38,
0x6c,
0xc6,
0xc6,
0x00,
0x00,
0x00,
0x00,

/* Character y (0x79):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   |**   ** |
   |**   ** |
   |**   ** |
   |**   ** |
   |**  *** |
   | *** ** |
   |     ** |
   |**   ** |
   | *****  |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0xc6,
0xc6,
0xc6,
0xc6,
0xce,
0x76,
0x06,
0xc6,
0x7c,
0x00,
0x00,

/* Character z (0x7a):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   |******* |
   |*    ** |
   |    **  |
   |   **   |
   |  **    |
   | **   * |
   |******* |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0xfe,
0x86,
0x0c,
0x18,
0x30,
0x62,
0xfe,
0x00,
0x00,
0x00,
0x00,

/* Character { (0x7b):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |    *** |
   |   **   |
   |   **   |
   |   **   |
   | ***    |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |    *** |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x0e,
0x18,
0x18,
0x18,
0x70,
0x18,
0x18,
0x18,
0x18,
0x0e,
0x00,
0x00,
0x00,
0x00,

/* Character | (0x7c):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |        |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x18,
0x18,
0x18,
0x18,
0x00,
0x18,
0x18,
0x18,
0x18,
0x18,
0x00,
0x00,
0x00,
0x00,

/* Character } (0x7d):
   ht=16, width=8
   +--------+
   |        |
   |        |
   | ***    |
   |   **   |
   |   **   |
   |   **   |
   |    *** |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   | ***    |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x70,
0x18,
0x18,
0x18,
0x0e,
0x18,
0x18,
0x18,
0x18,
0x70,
0x00,
0x00,
0x00,
0x00,

/* Character ~ (0x7e):
   ht=16, width=8
   +--------+
   |        |
   |        |
   | *** ** |
   |** ***  |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x76,
0xdc,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character  (0x7f):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   |   *    |
   |  ***   |
   |  ***   |
   | ** **  |
   | ** **  |
   |******* |
   |        |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x10,
0x38,
0x38,
0x6c,
0x6c,
0xfe,
0x00,
0x00,
0x00,
0x00,
0x00,

};
